.. _high_level_doc:

========================
High level documentation
========================

.. _inputs_setup:

Inputs setup
------------
.. automethod:: mater.model.Mater._inputs_setup

Outputs setup
-------------
.. automethod:: mater.model.Mater._outputs_setup

Self disposal, recycling and control flows computation
------------------------------------------------------
.. automethod:: mater.model.Mater._self_disposal_recycling_control_flows_computation

Processes computation
---------------------
.. automethod:: mater.model.Mater._processes_computation

Extraneous flows computation
----------------------------
.. automethod:: mater.model.Mater._extraneous_flows_computation

Objects computation
-------------------
.. automethod:: mater.model.Mater._objects_computation

Outputs update
--------------
.. autofunction:: mater.model.Mater._outputs_update

Outputs save
------------
.. automethod:: mater.model.Mater._outputs_save
